@@ -25,14 +25,14 @@ OC.L10N.register(
     "Provide federated file sharing across servers" : "Provide federated file sharing across servers",
     "Confirm data upload to lookup server" : "Confirm data upload to lookup server",
     "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book.",
-    "Disable upload" : "Disable upload",
     "Enable data upload" : "Enable data upload",
+    "Disable upload" : "Disable upload",
     "Confirm querying lookup server" : "Confirm querying lookup server",
     "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book.",
     "This is used to retrieve the federated cloud ID to make federated sharing easier." : "This is used to retrieve the federated cloud ID to make federated sharing easier.",
     "Moreover, email addresses of users might be sent to that system in order to verify them." : "Moreover, email addresses of users might be sent to that system in order to verify them.",
-    "Disable querying" : "Disable querying",
     "Enable querying" : "Enable querying",
+    "Disable querying" : "Disable querying",
     "Unable to update federated files sharing config" : "Unable to update federated files sharing config",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)",
@@ -46,26 +46,31 @@ OC.L10N.register(
     "Automatically accept shares from trusted federated accounts and groups by default" : "Automatically accept shares from trusted federated accounts and groups by default",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Share with me through my #Nextcloud Federated Cloud ID, see {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Share with me through my #Nextcloud Federated Cloud ID",
-    "Cloud ID copied to the clipboard" : "Cloud ID copied to the clipboard",
-    "Copy to clipboard" : "Copy to clipboard",
+    "Share with me via Nextcloud" : "Share with me via Nextcloud",
+    "Cloud ID copied" : "Cloud ID copied",
+    "Copy" : "Copy",
     "Clipboard not available. Please copy the cloud ID manually." : "Clipboard not available. Please copy the cloud ID manually.",
     "Copied!" : "Copied!",
     "Federated Cloud" : "Federated Cloud",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialogue. It looks like person@cloud.example.com",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com",
     "Your Federated Cloud ID" : "Your Federated Cloud ID",
     "Share it so your friends can share files with you:" : "Share it so your friends can share files with you:",
+    "Bluesky" : "Bluesky",
     "Facebook" : "Facebook",
-    "X (formerly Twitter)" : "X (formerly Twitter)",
-    "formerly Twitter" : "formerly Twitter",
     "Mastodon" : "Mastodon",
     "Add to your website" : "Add to your website",
-    "Share with me via Nextcloud" : "Share with me via Nextcloud",
+    "Share with me via {productName}" : "Share with me via {productName}",
     "HTML Code:" : "HTML Code:",
     "Cancel" : "Cancel",
     "Add remote share" : "Add remote share",
     "Remote share" : "Remote share",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Do you want to add the remote share {name} from {owner}@{remote}?",
     "Remote share password" : "Remote share password",
-    "Incoming share could not be processed" : "Incoming share could not be processed"
+    "Incoming share could not be processed" : "Incoming share could not be processed",
+    "Cloud ID copied to the clipboard" : "Cloud ID copied to the clipboard",
+    "Copy to clipboard" : "Copy to clipboard",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialogue. It looks like person@cloud.example.com",
+    "X (formerly Twitter)" : "X (formerly Twitter)",
+    "formerly Twitter" : "formerly Twitter"
 },
 "nplurals=2; plural=(n != 1);");
