@@ -78,6 +78,8 @@ OC.L10N.register(
     "Reload current directory" : "カレントディレクトリの再読み込み",
     "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
     "Current directory path" : "現在のディレクトリパス",
+    "Share" : "共有",
+    "Reload content" : "コンテンツを再読み込み",
     "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
     "You do not have permission to upload or create files here." : "ここにファイルをアップロードまたは作成する権限がありません。",
     "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
@@ -92,7 +94,6 @@ OC.L10N.register(
     "This node is unavailable" : "このノードは利用できません",
     "Another entry with the same name already exists." : "同じ名前の別のエントリがすでに存在しています。",
     "Invalid filename." : "無効なファイル名。",
-    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
     "Rename file" : "ファイル名の変更",
     "Folder" : "フォルダー",
     "Unknown file type" : "不明なファイルタイプ",
@@ -102,21 +103,71 @@ OC.L10N.register(
     "{ext} text" : "{ext}テキスト",
     "Pending" : "保留中",
     "Unknown date" : "不明な日付",
-    "Clear filter" : "フィルターをクリア",
-    "Modified" : "更新日時",
-    "Search everywhere" : "あらゆる場所を検索",
-    "Type" : "タイプ",
     "Active filters" : "有効なフィルター",
     "Remove filter" : "フィルターを削除",
+    "Today" : "今日",
+    "Last 7 days" : "7日以内",
+    "Last 30 days" : "30日以内",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Custom range" : "カスタム範囲",
+    "Custom date range" : "カスタム日付の範囲",
+    "Search everywhere" : "あらゆる場所を検索",
+    "Documents" : "ドキュメント",
+    "Spreadsheets" : "スプレッドシート",
+    "Presentations" : "プレゼンテーション",
+    "PDFs" : "PDF",
+    "Folders" : "フォルダー",
+    "Audio" : "オーディオ",
+    "Images" : "画像",
+    "Videos" : "動画",
+    "Filters" : "フィルター",
+    "Back to filters" : "フィルターに戻る",
+    "Appearance" : "表示",
+    "Show hidden files" : "隠しファイルを表示",
+    "Show file type column" : "ファイルの種類のカラムを表示する",
+    "Show file extensions" : "ファイルの拡張子を表示",
+    "Crop image previews" : "プレビュー画像を切り抜く",
+    "General" : "一般",
+    "Sort favorites first" : "お気に入りを最初に並べる",
+    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
+    "Enable folder tree view" : "フォルダーツリー表示を有効にする",
+    "Default view" : "デフォルト表示",
+    "All files" : "すべてのファイル",
+    "Personal files" : "個人ファイル",
+    "Additional settings" : "追加設定",
+    "Actions" : "アクション",
+    "File actions" : "ファイルアクション",
+    "Selection" : "選択",
+    "Select all files" : "全てのファイルを選択",
+    "Deselect all" : "選択を全解除",
+    "Select or deselect" : "選択または解除",
+    "Select a range" : "範囲を選択",
+    "Navigation" : "ナビゲーション",
+    "Go to parent folder" : "親フォルダーへ移動",
+    "Go to file above" : "上のファイルに移動",
+    "Go to file below" : "下のファイルに移動",
+    "Go left in grid" : "グリッド内を左に移動",
+    "Go right in grid" : "グリッド内を右に移動",
+    "View" : "表示",
+    "Toggle grid view" : "グリッド表示の切り替え",
+    "Show those shortcuts" : "これらのショートカットを表示する",
+    "Warnings" : "警告",
+    "Warn before changing a file extension" : "ファイル拡張子を変更する前に警告する",
+    "Warn before deleting a file" : "ファイルを削除する前に警告する",
+    "WebDAV URL" : "WebDAV URL",
+    "Create an app password" : "アプリパスワードを作成する",
+    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "このアカウントでは二要素認証が有効化されているため、WebDAV認証に必要です。",
+    "How to access files using WebDAV" : "WebDAVを使用してファイルにアクセスする方法",
     "Total rows summary" : "総行数のサマリー",
     "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
     "Name" : "名前",
     "File type" : "ファイルの種類",
     "Size" : "サイズ",
+    "Modified" : "更新日時",
     "{displayName}: failed on some elements" : "{displayName}: いくつかの要素で失敗しました",
     "{displayName}: done" : "{displayName}: 完了",
     "{displayName}: failed" : "{displayName}: 失敗",
-    "Actions" : "アクション",
     "(selected)" : "(選択済み)",
     "List of files and folders." : "ファイルとフォルダの一覧。",
     "You have used your space quota and cannot upload files anymore." : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
@@ -124,10 +175,11 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
     "File not found" : "ファイルが見つかりません",
     "_{count} selected_::_{count} selected_" : ["{count}選択済み"],
-    "Search everywhere …" : "あらゆる場所を検索 …",
-    "Search here …" : "ここを検索 …",
+    "Search everywhere …" : "あらゆる場所を検索 …",
+    "Search here …" : "ここを検索 …",
     "Search scope options" : "検索範囲オプション",
     "Search here" : "ここを検索",
+    "Owner" : "作成者",
     "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
     "{used} of {quota} used" : "{used} / {quota} 使用中",
     "{relative}% used" : "{relative}% 使用されています",
@@ -144,7 +196,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "ファイル名のサニタイズステータスの更新に失敗しました。",
     "Filename sanitization in progress." : "ファイル名のサニタイズが進行中です。",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "現在、{totalUsers}アカウントの{processedUsers}はすでに処理されています。",
-    "Preparing …" : "準備中 …",
+    "Preparing …" : "準備中 …",
     "Refresh" : "更新",
     "All files have been santized for Windows filename support." : "全てのファイルはWindowsファイル名をサポートするようにサンタイジングされています。",
     "Some files could not be sanitized, please check your logs." : "一部のファイルをサニタイズできませんでした。ログを確認してください。",
@@ -159,7 +211,7 @@ OC.L10N.register(
     "Sanitize filenames" : "ファイル名のサニタイズ",
     "(starting)" : "(開始)",
     "Fill template fields" : "テンプレートフィールドへの入力",
-    "Submitting fields …" : "フィールドを送信中…",
+    "Submitting fields …" : "フィールドを送信中…",
     "Submit" : "提出する",
     "Choose a file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Transfer" : "転送",
@@ -181,11 +233,14 @@ OC.L10N.register(
     "Removing the file extension \"{old}\" may render the file unreadable." : "ファイル拡張子 \"{old}\" を削除すると、ファイルが読み取れなくなる可能性があります。",
     "Adding the file extension \"{new}\" may render the file unreadable." : "ファイル拡張子 \"{new}\" を追加すると、ファイルが読み取れなくなる可能性があります。",
     "Do not show this dialog again." : "このダイアログを二度と表示しない。",
+    "Rename file to hidden" : "ファイルを隠しファイルに名前を変更する",
+    "Prefixing a filename with a dot may render the file hidden." : "ファイル名の先頭にドットを付けると、そのファイルが非表示になる場合があります。",
+    "Are you sure you want to rename the file to \"{filename}\"?" : "ファイル名を\"{filename}\"に変更してもよろしいですか？",
+    "Cancel" : "キャンセル",
+    "Rename" : "名前の変更",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
     "Choose {file}" : "{file}を選択",
-    "Share" : "共有",
-    "Shared by link" : "URLリンクで共有中",
-    "Shared" : "共有中",
+    "Files settings" : "ファイルの設定",
     "Switch to list view" : "リスト表示へ切り替え",
     "Switch to grid view" : "グリッド表示へ切り替え",
     "The file could not be found" : "ファイルが見つかりませんでした",
@@ -195,96 +250,46 @@ OC.L10N.register(
     "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
     "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
     "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
+    "File list is reloading" : "ファイルリストを再読み込み中",
     "Loading current folder" : "現在のフォルダの読み込み中",
     "Retry" : "リトライ",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
     "Go back" : "戻る",
     "Views" : "表示",
-    "Files settings" : "ファイルの設定",
+    "Loading …" : "読み込み中…",
     "Your files" : "あなたのファイル",
     "Open in files" : "ファイルで開く",
     "File cannot be accessed" : "ファイルにアクセスできません",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ファイルが見つからないか、あなたがそれを表示する権限を持っていない可能性があります。送信者に共有するように依頼してください。",
     "No search results for “{query}”" : "\"{query}\"に関する検索結果はありません",
     "Search for files" : "ファイルを検索",
-    "Clipboard is not available" : "クリップボードは利用できません",
-    "WebDAV URL copied" : "WebDAV URLをコピーしました",
-    "General" : "一般",
-    "Default view" : "デフォルト表示",
-    "All files" : "すべてのファイル",
-    "Personal files" : "個人ファイル",
-    "Sort favorites first" : "お気に入りを最初に並べる",
-    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
-    "Folder tree" : "フォルダーツリー",
-    "Appearance" : "表示",
-    "Show hidden files" : "隠しファイルを表示",
-    "Show file type column" : "ファイルの種類のカラムを表示する",
-    "Show file extensions" : "ファイルの拡張子を表示",
-    "Crop image previews" : "プレビュー画像を切り抜く",
-    "Additional settings" : "追加設定",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "コピー",
-    "How to access files using WebDAV" : "WebDAVを使用してファイルにアクセスする方法",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "2要素認証がアカウントに有効化されています。そのため、外部WebDAVクライアントを接続するにはアプリパスワードを使用する必要があります。",
-    "Warnings" : "警告",
-    "Warn before changing a file extension" : "ファイル拡張子を変更する前に警告する",
-    "Warn before deleting files" : "ファイルを削除する前に警告する",
-    "Keyboard shortcuts" : "キーボードショートカット",
-    "File actions" : "ファイルアクション",
-    "Rename" : "名前の変更",
-    "Delete" : "削除",
-    "Add or remove favorite" : "お気に入りを追加または削除",
-    "Manage tags" : "タグを管理",
-    "Selection" : "選択",
-    "Select all files" : "全てのファイルを選択",
-    "Deselect all" : "選択を全解除",
-    "Select or deselect" : "選択または解除",
-    "Select a range" : "範囲を選択",
-    "Navigation" : "ナビゲーション",
-    "Go to parent folder" : "親フォルダーへ移動",
-    "Go to file above" : "上のファイルに移動",
-    "Go to file below" : "下のファイルに移動",
-    "Go left in grid" : "グリッド内を左に移動",
-    "Go right in grid" : "グリッド内を右に移動",
-    "View" : "表示",
-    "Toggle grid view" : "グリッド表示の切り替え",
-    "Open file sidebar" : "ファイルサイドバーを開く",
-    "Show those shortcuts" : "これらのショートカットを表示する",
     "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "ファイルをすべてのクライアントと同期できるようにするために、ファイル名を制限することを許可します。デフォルトではPOSIX（LinuxやmacOSなど）で有効なすべてのファイル名が許可されています。",
     "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
     "Failed to toggle Windows filename support" : "Windowsファイル名サポートの切り替えに失敗しました",
     "Files compatibility" : "ファイルの互換性",
     "Enforce Windows compatibility" : "Windowsとの互換性を強制",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "予約名や特殊文字のような、Windowsシステムにおいて有効でないファイル名をブロックします。これは大文字、小文字の互換性を強制するものではありません。",
-    "You" : "自分",
-    "Shared multiple times with different people" : "異なる人と複数回共有",
-    "Unable to change the favorite state of the file" : "ファイルのお気に入りの状態を変更できません",
-    "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
-    "Owner" : "作成者",
-    "Remove from favorites" : "お気に入りから削除",
-    "Add to favorites" : "お気に入りに追加",
-    "Tags" : "タグ",
     "Blank" : "ブランク",
     "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
     "Pick a template for {name}" : "{name} のテンプレートを選択してください",
     "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
     "Creating file" : "ファイル作成",
     "Save as {displayName}" : "{displayName}として保存",
-    "Save as …" : "保存…",
-    "Converting files …" : "ファイルの変換…",
+    "Save as …" : "保存…",
+    "Converting files …" : "ファイルの変換…",
     "Failed to convert files: {message}" : "ファイルの変換に失敗しました: {message}",
     "All files failed to be converted" : "すべてのファイルの変換に失敗しました",
     "One file could not be converted: {message}" : "1つのファイルが変換できませんでした: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["%n個のファイルが変換できませんでした"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["%n個のファイルの変換に成功しました"],
-    "Files successfully converted" : "ファイルは正常に変換されました",
+    "_%n file could not be converted_::_%n files could not be converted_" : ["%n個のファイルが変換できませんでした"],
+    "_%n file converted_::_%n files converted_" : ["%n 個のファイルが変換されました"],
+    "Files converted" : "ファイルが変換されました",
     "Failed to convert files" : "ファイルの変換に失敗しました",
-    "Converting file …" : "ファイルの変換…",
+    "Converting file …" : "ファイルの変換…",
     "File successfully converted" : "ファイルは正常に変換されました",
     "Failed to convert file: {message}" : "ファイルの変換に失敗しました: {message}",
     "Failed to convert file" : "ファイルの変換に失敗しました",
+    "Delete" : "削除",
     "Leave this share" : "この共有から抜ける",
     "Leave these shares" : "これらの共有から抜ける",
     "Disconnect storage" : "ストレージを切断する",
@@ -298,26 +303,30 @@ OC.L10N.register(
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["{count}アイテムを完全に削除しようとしています"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["あなたは {count} 個のアイテムを削除しようとしています"],
     "Confirm deletion" : "削除の確認",
-    "Cancel" : "キャンセル",
     "Download" : "ダウンロード",
     "The requested file is not available." : "要求されたファイルは使用できません。",
     "The requested files are not available." : "要求されたファイルは使用できません。",
-    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
-    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "Add to favorites" : "お気に入りに追加",
+    "Remove from favorites" : "お気に入りから削除",
+    "Add or remove favorite" : "お気に入りを追加または削除",
+    "Move" : "移動",
+    "Copy" : "コピー",
+    "Move or copy" : "移動またはコピー",
     "Destination is not a folder" : "宛先がフォルダではありません",
     "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
-    "(copy)" : "(copy)",
-    "(copy %n)" : "(copy %n)",
     "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
     "The files are locked" : "ファイルはロックされています",
     "The file does not exist anymore" : "ファイルはもう存在しません",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
+    "Moving {count} files to \"{destination}\" …" : "{count} 個のファイルを \"{destination}\" に移動中…",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "Copying {count} files to \"{destination}\" …" : "{count}個のファイルを \"{destination}\" にコピー中…",
     "Choose destination" : "移動先を選択",
     "Copy to {target}" : "{target} にコピー",
     "Move to {target}" : "{target} に移動",
-    "Move" : "移動",
     "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
-    "Move or copy" : "移動またはコピー",
+    "Open folder" : "フォルダーを開く",
     "Open folder {displayName}" : "フォルダ {displayName} を開く",
     "Open in Files" : "ファイルアプリで開く",
     "Open locally" : "ローカルで開く",
@@ -327,26 +336,17 @@ OC.L10N.register(
     "Retry and close" : "再試行して閉じる",
     "Open online" : "オンラインで開く",
     "Details" : "詳細",
+    "Open the details sidebar" : "詳細サイドバーを開く",
+    "Unfavorite" : "お気に入りから外す",
     "View in folder" : "フォルダー内で表示",
-    "Today" : "今日",
-    "Last 7 days" : "7日以内",
-    "Last 30 days" : "30日以内",
-    "This year ({year})" : "今年 ({year})",
-    "Last year ({year})" : "去年 ({year})",
-    "Documents" : "ドキュメント",
-    "Spreadsheets" : "スプレッドシート",
-    "Presentations" : "プレゼンテーション",
-    "PDFs" : "PDF",
-    "Folders" : "フォルダー",
-    "Audio" : "オーディオ",
-    "Images" : "画像",
-    "Videos" : "動画",
+    "Type" : "タイプ",
     "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
     "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
     "Create templates folder" : "テンプレートフォルダーの作成",
     "Templates" : "テンプレート",
     "New template folder" : "新しいテンプレートフォルダ",
     "In folder" : "フォルダ内",
+    "Pick folder to search in" : "検索対象のフォルダーを選択してください",
     "Search in all files" : "すべてのファイルを検索",
     "Search in folder: {folder}" : "フォルダ内を検索: {folder}",
     "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
@@ -356,10 +356,10 @@ OC.L10N.register(
     "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
     "Files uploaded successfully" : "ファイルが正常にアップロードされました",
     "No files to process" : "処理するファイルがありません",
-    "Some files could not be copied" : "いくつかのファイルがコピーできません",
-    "Some files could not be moved" : "いくつかのファイルが移動できません",
     "Files copied successfully" : "ファイルが正常にコピーされました",
     "Files moved successfully" : "ファイルの移動に成功しました",
+    "Some files could not be copied" : "いくつかのファイルがコピーできません",
+    "Some files could not be moved" : "いくつかのファイルが移動できません",
     "Conflicts resolution skipped" : "コンフリクトの解決はスキップされました",
     "Upload cancelled" : "アップロードはキャンセルされました",
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
@@ -381,6 +381,7 @@ OC.L10N.register(
     "No favorites yet" : "まだお気に入りはありません",
     "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
     "List of your files and folders." : "ファイルやフォルダーの一覧",
+    "Folder tree" : "フォルダーツリー",
     "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
     "No personal files found" : "個人ファイルは見つかりませんでした",
     "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
@@ -394,119 +395,32 @@ OC.L10N.register(
     "Select all" : "すべて選択",
     "Upload too large" : "アップロードには大きすぎます。",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
-    "File could not be found" : "ファイルを見つけられませんでした",
-    "Show list view" : "リストビューで表示",
-    "Show grid view" : "グリッドビューで表示",
-    "Close" : "閉じる",
-    "Could not create folder \"{dir}\"" : "フォルダー \"{dir}\" を作成できませんでした",
-    "This will stop your current uploads." : "現在のアップロードが停止されます。",
-    "Upload cancelled." : "アップロードはキャンセルされました。",
-    "Processing files …" : "ファイルの処理中...",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "ディレクトリであるか、または0バイトのため {filename} をアップロードできません",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "空き容量が十分でなく、 {size1} をアップロードしていますが、 {size2} しか残っていません。",
-    "Target folder \"{dir}\" does not exist any more" : "対象フォルダー \"{dir}\" がもう存在しません",
-    "An unknown error has occurred" : "不明なエラーが発生しました",
-    "File could not be uploaded" : "ファイルをアップロードできませんでした",
-    "Uploading …" : "アップロード中...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "アップロード中… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中 {loadedSize} ({bitrate})",
-    "Uploading that item is not supported" : "そのアイテムのアップロードに対応していません",
-    "Error when assembling chunks, status code {status}" : "チャンクを組み立てる際のエラー、ステータスコード{status}",
-    "Choose target folder" : "ターゲットフォルダーを選択",
-    "Set reminder" : "リマインダーを設定",
-    "Edit locally" : "ローカルで編集",
-    "Open" : "開く",
-    "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
-    "Please select tag(s) to add to the selection" : "選択項目に付与するタグを選択してください",
-    "Apply tag(s) to selection" : "選択項目にタグを適用",
-    "Select directory \"{dirName}\"" : "ディレクトリを選択: \"{dirName}\"",
-    "Select file \"{fileName}\"" : "ファイルを選択: \"{fileName}\"",
-    "Unable to determine date" : "更新日不明",
-    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
-    "Could not move \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"を移動できませんでした",
-    "Could not move \"{file}\"" : "\"{file}\" を移動できませんでした",
-    "copy" : "コピー",
-    "Could not copy \"{file}\", target exists" : "ターゲットが存在するため，ファイル \"{file}\"をコピーできませんでした",
-    "Could not copy \"{file}\"" : "\"{file}\"をコピーできませんでした",
-    "Copied {origin} inside {destination}" : "コピー先{origin} {destination}内",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "コピー先{origin}と{nbfiles}他のファイル{destination}",
-    "{newName} already exists" : "{newName} はすでに存在します",
-    "Could not create file \"{file}\"" : "ファイル \"{file}\" を作成できませんでした",
-    "Could not create file \"{file}\" because it already exists" : "ファイル \"{file}\"はすでに存在するため作成できません",
-    "Could not create folder \"{dir}\" because it already exists" : "フォルダー \"{dir}\" はすでに存在するため作成できません",
-    "Could not fetch file details \"{file}\"" : "\"{file}\" の詳細が取得できませんでした",
-    "Error deleting file \"{fileName}\"." : "ファイル\"{fileName}\"の削除エラー。",
-    "No search results in other folders for {tag}{filter}{endtag}" : "他のフォルダーに {tag}{filter}{endtag} の検索結果はありません",
-    "Enter more than two characters to search in other folders" : "他のフォルダーで検索するには、3文字以上を入力してください",
-    "{dirs} and {files}" : "{dirs} と {files}",
-    "_including %n hidden_::_including %n hidden_" : ["%n 個の隠しファイルが含まれています"],
-    "You do not have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
-    "_Uploading %n file_::_Uploading %n files_" : ["%n 個のファイルをアップロード中"],
-    "New" : "新規作成",
-    "New file/folder menu" : "新規ファイル/フォルダメニュー",
-    "Select file range" : "ファイルを範囲選択",
-    "{used}%" : "{used}%",
-    "{used} used" : "{used} 使用中",
-    "\"{name}\" is an invalid file name." : "\"{name}\" は無効なファイル名です。",
-    "File name cannot be empty." : "ファイル名を空にすることはできません。",
-    "\"/\" is not allowed inside a file name." : "\"/\" はファイル名に利用できません。",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" は無効なファイル形式です",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} のストレージは一杯です。ファイルの更新と同期はできません！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "グループフォルダー ”{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部ストレージ \"{mountPoint}\" がいっぱいになり、ファイルを更新または同期できなくなりました。",
-    "Your storage is full, files cannot be updated or synced anymore!" : "ストレージがいっぱいで、ファイルを更新または同期できなくなりました。",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} のストレージがほぼ一杯 ({usedSpacePercent}％) です",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "グループフォルダー \"{mountPoint}\" がほぼいっぱい ({usedSpacePercent}％) です。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部ストレージ \"{mountPoint}\" はほぼいっぱい ({usedSpacePercent}％) です",
-    "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
-    "Path" : "Path",
-    "_%n byte_::_%n bytes_" : ["%n バイト"],
-    "Favored" : "好評",
-    "Favor" : "好意的",
-    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
-    "Upload file" : "ファイルをアップロード",
-    "Not favored" : "好ましくない",
-    "An error occurred while trying to update the tags" : "タグを更新する際にエラーが発生しました",
+    "%1$s (renamed)" : "%1$s (リネーム済み)",
+    "renamed file" : "リネーム済みファイル",
     "Upload (max. %s)" : "アップロード ( 最大 %s )",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行されました",
-    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "この設定を有効にした後、自動的にファイルを移行することも可能です。occコマンドに関するドキュメントを参照してください。",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" から \"{newName}\" に名前を変更済み",
+    "Clear filter" : "フィルターをクリア",
     "\"{displayName}\" failed on some elements" : "いくつかの要素で \"{displayName}\" が失敗しました。",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
-    "Submitting fields…" : "フィールドを送信中…",
-    "Filter filenames…" : "ファイルネームフィルター…",
+    "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
+    "Submitting fields …" : "フィールドを送信中…",
+    "Shared by link" : "URLリンクで共有中",
+    "Shared" : "共有中",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行されました",
+    "Filter file names …" : "ファイルネームフィルター…",
+    "Clipboard is not available" : "クリップボードは利用できません",
     "WebDAV URL copied to clipboard" : "WebDAVのURLがクリップボードにコピーされました",
     "Enable the grid view" : "グリッド表示を有効にする",
     "Enable folder tree" : "フォルダーツリーを有効にする",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "クリップボードにコピー",
     "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
-    "Deletion cancelled" : "削除はキャンセルされました",
-    "Move cancelled" : "移動はキャンセルされました",
-    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
-    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
-    "Open details" : "詳細を開く",
-    "Photos and images" : "写真と画像",
-    "New folder creation cancelled" : "新しいフォルダーの作成がキャンセルされました",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ファイルと 1 フォルダ"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ファイルと {folderCount} フォルダ",
-    "All folders" : "全てのフォルダー",
-    "Personal Files" : "個人ファイル",
-    "Text file" : "テキストファイル",
-    "New text file.txt" : "新規のテキストファイル作成",
-    "%1$s (renamed)" : "%1$s (リネーム済み)",
-    "renamed file" : "リネーム済みファイル",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows 互換のファイル名を有効にすると、既存のファイルは変更できなくなりますが、所有者が有効な新しいファイル名に変更できるようになります。",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "この設定を有効にした後、自動的にファイルを移行することも可能です。occコマンドに関するドキュメントを参照してください。",
-    "Filter file names …" : "ファイルネームフィルター…",
     "Prevent warning dialogs from open or reenable them." : "警告ダイアログが開かないようにするか、再度有効にする。",
     "Show a warning dialog when changing a file extension." : "ファイルの拡張子を変更する際に、警告ダイアログを表示する。",
+    "Keyboard shortcuts" : "キーボードショートカット",
     "Speed up your Files experience with these quick shortcuts." : "これらのショートカットでファイルの取り扱いを高速化します",
     "Open the actions menu for a file" : "ファイルのアクションメニューを開く",
     "Rename a file" : "ファイル名を変更",
@@ -522,6 +436,32 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "左のファイルに移動（グリッドモード）",
     "Navigate to the file on the right (in grid mode)" : "右のファイルに移動（グリッドモード）",
     "Toggle the grid view" : "グリッドビューを切り替え",
-    "Open the sidebar for a file" : "ファイルのサイドバーを開く"
+    "Open the sidebar for a file" : "ファイルのサイドバーを開く",
+    "You" : "自分",
+    "Shared multiple times with different people" : "異なる人と複数回共有",
+    "Unable to change the favorite state of the file" : "ファイルのお気に入りの状態を変更できません",
+    "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
+    "Tags" : "タグ",
+    "Save as …" : "保存…",
+    "Converting files …" : "ファイルの変換…",
+    "Converting file …" : "ファイルの変換…",
+    "Deletion cancelled" : "削除はキャンセルされました",
+    "Edit locally" : "ローカルで編集",
+    "Moving \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"に移動",
+    "Copying \"{source}\" to \"{destination}\" …" : "\"{source}\" を \"{destination}\"にコピー",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
+    "Move cancelled" : "移動はキャンセルされました",
+    "Cancelled move or copy of \"{filename}\"." : "\"{filename}\"の移動またはコピーをキャンセルしました。",
+    "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
+    "Open details" : "詳細を開く",
+    "Photos and images" : "写真と画像",
+    "New folder creation cancelled" : "新しいフォルダーの作成がキャンセルされました",
+    "This directory is unavailable, please check the logs or contact the administrator" : "このディレクトリは利用できません。ログを確認するか管理者に問い合わせてください。",
+    "All folders" : "全てのフォルダー",
+    "Open file sidebar" : "ファイルサイドバーを開く",
+    "Search everywhere …" : "あらゆる場所を検索 …",
+    "Search here …" : "ここを検索 …",
+    "Preparing …" : "準備中 …"
 },
 "nplurals=1; plural=0;");
